@@ -19,7 +19,7 @@
 #ifndef vte_vte_h_included
 #define vte_vte_h_included
 
-#ident "$Id: vte.h,v 1.54 2002/10/30 20:03:22 nalin Exp $"
+#ident "$Id: vte.h,v 1.56 2002/11/05 22:54:20 nalin Exp $"
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -88,8 +88,8 @@ struct _VteTerminalClass {
 	guint status_line_changed_signal;
 	guint commit_signal;
 
-	gpointer reserved1;
-	gpointer reserved2;
+	guint increase_font_size_signal;
+	guint decrease_font_size_signal;
 	gpointer reserved3;
 	gpointer reserved4;
 };
@@ -107,7 +107,7 @@ typedef enum {
 struct vte_char_attributes {
 	long row, column;
 	GdkColor fore, back;
-	gboolean underline, alternate;
+	gboolean underline:1, alternate:1, strikethrough:1;
 };
 
 /* The widget's type. */
